package nz.ac.massey.javaecs;
/**
 * ECS System class
 * This class stores entity-system registrations. These are
 * updated by SystemManager, but need a type to store the
 * data under.
 * 
 * All systems should inherit from this
 * 
 * Contributors:
 * Brychan Dempsey - brychand@hotmail.com
 * 
 */

import java.util.Set;
import java.util.BitSet;
import java.util.HashSet;

public abstract class ECSSystem{
    protected Set<Entity> entities = new HashSet<>();
    protected BitSet registrationSet;

    public BitSet getRegistrationSet(){
        return registrationSet;
    }

    /**
     * Functionality that should be run only once.
     * Implement additional parameterised init() functions as required.
     */
    public abstract void init();
    
    /**
     * Functionality that is expected to be called regularly
     * Intended as a template only; may be superficially implemented.
     * Implement additional parameterised update() functions as required.
     * @param dt delta-time; the change in time in milliseconds since this function was last run
     */
    public abstract void update(double dt);
}